@@ -63,7 +63,6 @@ class DatabaseClient:
         Retuns: JSON Object.
         """
         sdata = json.dumps(data)
-        print(sdata)
         sdata = str(base64.b64encode(hashlib.md5(bytes(sdata, encoding='utf8')).digest()), encoding='utf8')
         response = await self.requests.post(
             url=f"https://apis.roblox.com/datastores/v1/universes/{self.id}/standard-datastores/datastore/entries/entry",
@@ -120,11 +119,3 @@ class DatabaseClient:
 import asyncio
 ban_data = {'reason': 'sleep', 'BannedBy': 'xKen_t (1356185892)', 'PlayerName': 'xKen_t'}
 
-async def main_def():
-    print("Test 1")
-    client = DatabaseClient(universeId=3298669091, token="0bI1AKfEIEe9sDlo1DDI5vjvGeSiykFd6rfB2D/FM48nA200")
-    print("Test 2")
-    t = await client.set_data('banData', 1356185892, True)
-    print(t)
-
-asyncio.run(main_def())
\ No newline at end of file
